# Gidconfig

Configuration provider package, that exposes the section as attribute and also automatically keeps the config file and object in sync.

Through the Factory/Strategy the config objects are singletons as long as they point to the same file.


## Config File Formats Supported

- `ini`
- `json` (WIP)


## Status

```
Work In Progress
```